@@ -33,6 +33,7 @@ using std::string;
 
 constexpr auto const* DEFAULT_FONT = "Sans";
 constexpr auto DEFAULT_FONT_SIZE = 12;
+constexpr auto DEFAULT_TOOLBAR = "Portrait";
 
 #define SAVE_BOOL_PROP(var) xmlNode = saveProperty((const char*)#var, (var) ? "true" : "false", root)
 #define SAVE_STRING_PROP(var) xmlNode = saveProperty((const char*)#var, (var).empty() ? "" : (var).c_str(), root)
@@ -92,6 +93,7 @@ void Settings::loadDefault() {
     this->sidebarNumberingStyle = SidebarNumberingStyle::DEFAULT;
 
     this->showToolbar = true;
+    this->selectedToolbar = DEFAULT_TOOLBAR;
 
     this->sidebarOnRight = false;
 
@@ -114,6 +116,7 @@ void Settings::loadDefault() {
     this->useStockIcons = false;
     this->scrollbarHideType = SCROLLBAR_HIDE_NONE;
     this->disableScrollbarFadeout = false;
+    this->disableAudio = false;
 
     // Set this for autosave frequency in minutes.
     this->autosaveTimeout = 3;
@@ -368,7 +371,8 @@ void Settings::parseItem(xmlDocPtr doc, xmlNodePtr cur) {
     if (xmlStrcmp(name, reinterpret_cast<const xmlChar*>("pressureSensitivity")) == 0) {
         this->pressureSensitivity = xmlStrcmp(value, reinterpret_cast<const xmlChar*>("true")) == 0;
     } else if (xmlStrcmp(name, reinterpret_cast<const xmlChar*>("minimumPressure")) == 0) {
-        this->minimumPressure = g_ascii_strtod(reinterpret_cast<const char*>(value), nullptr);
+        // std::max is for backwards compatibility for users who might have set this value too small
+        this->minimumPressure = std::max(0.01, g_ascii_strtod(reinterpret_cast<const char*>(value), nullptr));
     } else if (xmlStrcmp(name, reinterpret_cast<const xmlChar*>("pressureMultiplier")) == 0) {
         this->pressureMultiplier = g_ascii_strtod(reinterpret_cast<const char*>(value), nullptr);
     } else if (xmlStrcmp(name, reinterpret_cast<const xmlChar*>("zoomGesturesEnabled")) == 0) {
@@ -547,6 +551,8 @@ void Settings::parseItem(xmlDocPtr doc, xmlNodePtr cur) {
         }
     } else if (xmlStrcmp(name, reinterpret_cast<const xmlChar*>("disableScrollbarFadeout")) == 0) {
         this->disableScrollbarFadeout = xmlStrcmp(value, reinterpret_cast<const xmlChar*>("true")) == 0;
+    } else if (xmlStrcmp(name, reinterpret_cast<const xmlChar*>("disableAudio")) == 0) {
+        this->disableAudio = xmlStrcmp(value, reinterpret_cast<const xmlChar*>("true")) == 0;
     } else if (xmlStrcmp(name, reinterpret_cast<const xmlChar*>("audioSampleRate")) == 0) {
         this->audioSampleRate = tempg_ascii_strtod(reinterpret_cast<const char*>(value), nullptr);
     } else if (xmlStrcmp(name, reinterpret_cast<const xmlChar*>("audioGain")) == 0) {
@@ -719,8 +725,8 @@ auto Settings::load() -> bool {
     xmlKeepBlanksDefault(0);
 
     if (!fs::exists(filepath)) {
-        g_warning("configfile does not exist %s\n", filepath.string().c_str());
-        return false;
+        g_warning("Settings file %s does not exist. Regenerating. ", filepath.string().c_str());
+        save();
     }
 
     xmlDocPtr doc = xmlParseFile(filepath.u8string().c_str());
@@ -975,6 +981,7 @@ void Settings::save() {
     SAVE_BOOL_PROP(useStockIcons);
 
     SAVE_BOOL_PROP(disableScrollbarFadeout);
+    SAVE_BOOL_PROP(disableAudio);
 
     if (this->scrollbarHideType == SCROLLBAR_HIDE_BOTH) {
         xmlNode = saveProperty("scrollbarHideType", "both", root);
@@ -2233,6 +2240,16 @@ void Settings::setScrollbarFadeoutDisabled(bool disable) {
     save();
 }
 
+auto Settings::isAudioDisabled() const -> bool { return disableAudio; }
+
+void Settings::setAudioDisabled(bool disable) {
+    if (disableAudio == disable) {
+        return;
+    }
+    disableAudio = disable;
+    save();
+}
+
 //////////////////////////////////////////////////
 
 SAttribute::SAttribute() {
