@@ -346,6 +346,9 @@ public:
     bool isScrollbarFadeoutDisabled() const;
     void setScrollbarFadeoutDisabled(bool disable);
 
+    bool isAudioDisabled() const;
+    void setAudioDisabled(bool disable);
+
     std::string const& getDefaultSaveName() const;
     void setDefaultSaveName(const std::string& name);
 
@@ -704,6 +707,11 @@ private:
      */
     bool disableScrollbarFadeout{};
 
+    /**
+     * Disable the audio system
+     */
+    bool disableAudio{};
+
     /**
      *  The selected Toolbar name
      */
